hatch_vcs: Hatch plugin for versioning with your preferred VCS
==============================================================

Description
-----------

Hatch plugin for versioning with your preferred VCS

License
-------

Upstream Contact
----------------

https://pypi.org/project/hatch-vcs/

